==> ejc-zdsstore-impl-3.0.0-20231206.084607-4-sources.jar: com/ejianc/business/zdsstore/bean/AllotInDetailEntity.java <==
package com.ejianc.business.zdsstore.bean;

import java.math.*;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 调拨入库子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_store_allot_in_detail")
public class AllotInDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    

    @TableField(value="allocat_id")
    private Long allocatId; // 主表id
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类id
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value="material_id")
    private Long materialId; // 物资id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_spec")
    private String materialSpec; // 规格型号
    @TableField(value="material_unit_id")
    private Long materialUnitId; // 物资计量单位id
    @TableField(value="material_unit")
    private String materialUnit; // 物资计量单位
    @TableField(value="surplus_num")
    private BigDecimal surplusNum; // 剩余可用数量
    @TableField(value="allocat_num")
    private BigDecimal allocatNum; // 调拨数量
    @TableField(value="allocat_price")
    private BigDecimal allocatPrice; // 调拨单价
    @TableField(value="allocat_tax_price")
    private BigDecimal allocatTaxPrice; // 调拨单价（有税）
    @TableField(value="allocat_tax_rate")
    private BigDecimal allocatTaxRate; // 调拨税率
    @TableField(value="allocat_mny")
    private BigDecimal allocatMny; // 调拨金额
    @TableField(value="allocat_tax_mny")
    private BigDecimal allocatTaxMny; // 调拨单价（有税）
    @TableField(value="allocat_tax")
    private BigDecimal allocatTax; // 调拨税额
    @TableField(value="in_store_average_price")
    private BigDecimal inStoreAveragePrice; // 入库均价
    @TableField(value="in_store_tax")
    private BigDecimal inStoreTax; // 入库税额
    @TableField(value="in_store_mny")
    private BigDecimal inStoreMny; // 入库金额
    @TableField(value="in_store_tax_mny")
    private BigDecimal inStoreTaxMny; // 入库金额（有税）
    @TableField(value="memo")
    private String memo; // 备注
     @TableField(value="in_store_tax_rate")
    private BigDecimal inStoreTaxRate; // 入库税率


    public Long getAllocatId() {
        return allocatId;
    }

    public void setAllocatId(Long allocatId) {
        this.allocatId = allocatId;
    }

    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }
    public String getMaterialUnit() {
        return materialUnit;
    }

    public void setMaterialUnit(String materialUnit) {
        this.materialUnit = materialUnit;
    }
    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }
    public BigDecimal getAllocatNum() {
        return allocatNum;
    }

    public void setAllocatNum(BigDecimal allocatNum) {
        this.allocatNum = allocatNum;
    }
    public BigDecimal getAllocatPrice() {
        return allocatPrice;
    }

    public void setAllocatPrice(BigDecimal allocatPrice) {
        this.allocatPrice = allocatPrice;
    }
    public BigDecimal getAllocatTaxPrice() {
        return allocatTaxPrice;
    }

    public void setAllocatTaxPrice(BigDecimal allocatTaxPrice) {
        this.allocatTaxPrice = allocatTaxPrice;
    }

    public BigDecimal getAllocatTaxRate() {
        return allocatTaxRate;
    }

    public void setAllocatTaxRate(BigDecimal allocatTaxRate) {
        this.allocatTaxRate = allocatTaxRate;
    }

    public BigDecimal getAllocatMny() {
        return allocatMny;
    }

    public void setAllocatMny(BigDecimal allocatMny) {
        this.allocatMny = allocatMny;
    }
    public BigDecimal getAllocatTaxMny() {
        return allocatTaxMny;
    }

    public void setAllocatTaxMny(BigDecimal allocatTaxMny) {
        this.allocatTaxMny = allocatTaxMny;
    }
    public BigDecimal getAllocatTax() {
        return allocatTax;
    }

    public void setAllocatTax(BigDecimal allocatTax) {
        this.allocatTax = allocatTax;
    }
    public BigDecimal getInStoreAveragePrice() {
        return inStoreAveragePrice;
    }

    public void setInStoreAveragePrice(BigDecimal inStoreAveragePrice) {
        this.inStoreAveragePrice = inStoreAveragePrice;
    }
    public BigDecimal getInStoreTax() {
        return inStoreTax;
    }

    public void setInStoreTax(BigDecimal inStoreTax) {
        this.inStoreTax = inStoreTax;
    }
    public BigDecimal getInStoreMny() {
        return inStoreMny;
    }

    public void setInStoreMny(BigDecimal inStoreMny) {
        this.inStoreMny = inStoreMny;
    }

    public BigDecimal getInStoreTaxMny() {
        return inStoreTaxMny;
    }

    public void setInStoreTaxMny(BigDecimal inStoreTaxMny) {
        this.inStoreTaxMny = inStoreTaxMny;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getInStoreTaxRate() {
        return inStoreTaxRate;
    }

    public void setInStoreTaxRate(BigDecimal inStoreTaxRate) {
        this.inStoreTaxRate = inStoreTaxRate;
    }
}

==> ejc-zdsstore-impl-3.0.0-20231221.090114-16-sources.jar: com/ejianc/business/zdsstore/bean/AllotInDetailEntity.java <==
package com.ejianc.business.zdsstore.bean;

import java.math.*;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 调拨入库子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_store_allot_in_detail")
public class AllotInDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    

    @TableField(value="allocat_id")
    private Long allocatId; // 主表id
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类id
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value="material_id")
    private Long materialId; // 物资id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_spec")
    private String materialSpec; // 规格型号
    @TableField(value="material_unit_id")
    private Long materialUnitId; // 物资计量单位id
    @TableField(value="material_unit")
    private String materialUnit; // 物资计量单位
    @TableField(value="surplus_num")
    private BigDecimal surplusNum; // 剩余可用数量
    @TableField(value="allocat_num")
    private BigDecimal allocatNum; // 调拨数量
    @TableField(value="allocat_price")
    private BigDecimal allocatPrice; // 调拨单价
    @TableField(value="allocat_tax_price")
    private BigDecimal allocatTaxPrice; // 调拨单价（有税）
    @TableField(value="allocat_tax_rate")
    private BigDecimal allocatTaxRate; // 调拨税率
    @TableField(value="allocat_mny")
    private BigDecimal allocatMny; // 调拨金额
    @TableField(value="allocat_tax_mny")
    private BigDecimal allocatTaxMny; // 调拨单价（有税）
    @TableField(value="allocat_tax")
    private BigDecimal allocatTax; // 调拨税额
    @TableField(value="in_store_average_price")
    private BigDecimal inStoreAveragePrice; // 入库均价
    @TableField(value="in_store_tax")
    private BigDecimal inStoreTax; // 入库税额
    @TableField(value="in_store_mny")
    private BigDecimal inStoreMny; // 入库金额
    @TableField(value="in_store_tax_mny")
    private BigDecimal inStoreTaxMny; // 入库金额（有税）
    @TableField(value="memo")
    private String memo; // 备注
     @TableField(value="in_store_tax_rate")
    private BigDecimal inStoreTaxRate; // 入库税率

    @TableField(value="brand_id")
    private Long brandId; //品牌主键
    @TableField(value="brand_name")
    private String brandName; // 品牌
    @TableField(value="asset_value")
    private String assetValue; // 资产价值
    @TableField(value = "product_code")
    private String productCode; // 产品代码
    @TableField(value = "detail_store_name")
    private String detailStoreName; // 仓库
    @TableField(value = "detail_store_id")
    private Long detailStoreId;//仓库id

    public String getDetailStoreName() {
        return detailStoreName;
    }

    public void setDetailStoreName(String detailStoreName) {
        this.detailStoreName = detailStoreName;
    }

    public Long getDetailStoreId() {
        return detailStoreId;
    }

    public void setDetailStoreId(Long detailStoreId) {
        this.detailStoreId = detailStoreId;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public String getAssetValue() {
        return assetValue;
    }

    public void setAssetValue(String assetValue) {
        this.assetValue = assetValue;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public Long getAllocatId() {
        return allocatId;
    }

    public void setAllocatId(Long allocatId) {
        this.allocatId = allocatId;
    }

    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }
    public String getMaterialUnit() {
        return materialUnit;
    }

    public void setMaterialUnit(String materialUnit) {
        this.materialUnit = materialUnit;
    }
    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }
    public BigDecimal getAllocatNum() {
        return allocatNum;
    }

    public void setAllocatNum(BigDecimal allocatNum) {
        this.allocatNum = allocatNum;
    }
    public BigDecimal getAllocatPrice() {
        return allocatPrice;
    }

    public void setAllocatPrice(BigDecimal allocatPrice) {
        this.allocatPrice = allocatPrice;
    }
    public BigDecimal getAllocatTaxPrice() {
        return allocatTaxPrice;
    }

    public void setAllocatTaxPrice(BigDecimal allocatTaxPrice) {
        this.allocatTaxPrice = allocatTaxPrice;
    }

    public BigDecimal getAllocatTaxRate() {
        return allocatTaxRate;
    }

    public void setAllocatTaxRate(BigDecimal allocatTaxRate) {
        this.allocatTaxRate = allocatTaxRate;
    }

    public BigDecimal getAllocatMny() {
        return allocatMny;
    }

    public void setAllocatMny(BigDecimal allocatMny) {
        this.allocatMny = allocatMny;
    }
    public BigDecimal getAllocatTaxMny() {
        return allocatTaxMny;
    }

    public void setAllocatTaxMny(BigDecimal allocatTaxMny) {
        this.allocatTaxMny = allocatTaxMny;
    }
    public BigDecimal getAllocatTax() {
        return allocatTax;
    }

    public void setAllocatTax(BigDecimal allocatTax) {
        this.allocatTax = allocatTax;
    }
    public BigDecimal getInStoreAveragePrice() {
        return inStoreAveragePrice;
    }

    public void setInStoreAveragePrice(BigDecimal inStoreAveragePrice) {
        this.inStoreAveragePrice = inStoreAveragePrice;
    }
    public BigDecimal getInStoreTax() {
        return inStoreTax;
    }

    public void setInStoreTax(BigDecimal inStoreTax) {
        this.inStoreTax = inStoreTax;
    }
    public BigDecimal getInStoreMny() {
        return inStoreMny;
    }

    public void setInStoreMny(BigDecimal inStoreMny) {
        this.inStoreMny = inStoreMny;
    }

    public BigDecimal getInStoreTaxMny() {
        return inStoreTaxMny;
    }

    public void setInStoreTaxMny(BigDecimal inStoreTaxMny) {
        this.inStoreTaxMny = inStoreTaxMny;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getInStoreTaxRate() {
        return inStoreTaxRate;
    }

    public void setInStoreTaxRate(BigDecimal inStoreTaxRate) {
        this.inStoreTaxRate = inStoreTaxRate;
    }
}
